@@ -1,5 +1,5 @@
 use crossterm::{
-    //    cursor::{CursorShape, SetCursorShape},
+    cursor::{CursorShape, SetCursorShape},
     event::{Event, KeyCode, KeyEvent, KeyModifiers},
     style::Color,
     terminal::ClearType,
@@ -641,6 +641,10 @@ impl IRust {
                 Ok(())
             }
             Command::Exit => {
+                if let Some(cmd) = self.shutdown_hook() {
+                    self.execute(cmd)?;
+                }
+
                 self.history.save()?;
                 self.options.save()?;
                 self.theme.save()?;
@@ -648,14 +652,14 @@ impl IRust {
                 self.printer.cursor.show();
                 Ok(())
             }
-            Command::SetThinCursor => Ok(()), /*Ok(crossterm::queue!(
-            std::io::stdout(),
-            SetCursorShape(CursorShape::Line)
-            )?),*/
-            Command::SetWideCursor => Ok(()), /*Ok(crossterm::queue!(
-                                                  std::io::stdout(),
-                                                  SetCursorShape(CursorShape::Block)
-                                              )?),*/
+            Command::SetThinCursor => Ok(crossterm::queue!(
+                std::io::stdout(),
+                SetCursorShape(CursorShape::Line)
+            )?),
+            Command::SetWideCursor => Ok(crossterm::queue!(
+                std::io::stdout(),
+                SetCursorShape(CursorShape::Block)
+            )?),
         }
     }
 
